@@ -28,7 +28,8 @@ diri.est <- function(x, type = 'mle') {
 
   if (type == 'mle') {
     runtime <- proc.time()
-    #suppressWarnings()
+    oop <- options( warn = -1 )
+    on.exit( options(oop) )
     da <- nlm(loglik, Rfast::colmeans(x) * 10, z = z, n = n, iterlim = 10000)
     da <- optim(da$estimate, loglik, z = z, n = n, control = list(maxit = 5000), hessian = TRUE)
     runtime <- proc.time() - runtime
@@ -38,7 +39,8 @@ diri.est <- function(x, type = 'mle') {
 
   if (type == 'prec') {
     runtime <- proc.time()
-    #suppressWarnings()
+    oop <- options( warn = -1 )
+    on.exit( options(oop) )
     da <- nlm(diriphi, c(10, Rfast::colmeans(x)[-1]), z = z, n = n, iterlim = 5000)
     da <- optim(da$estimate, diriphi, z = z, n = n, control = list(maxit = 5000), hessian = TRUE)
     phi <- exp(da$par[1])
