@@ -36,7 +36,8 @@ js.compreg <- function(y, x, con = TRUE, B = 1, ncores = 1, xnew = NULL) {
   ## the next lines minimize the kl.compreg function and obtain the estimated betas
   runtime <- proc.time()
   ini <- as.vector( t( Compositional::kl.compreg(y, x[, -1, drop = FALSE], con = con)$be ) )
-  #suppressWarnings()
+  oop <- options( warn = -1 )
+  on.exit( options(oop) )
   qa <- nlm(jsreg, ini, y = y, x = x, d = d)
   qa <- nlm(jsreg, qa$estimate, y = y, x = x, d = d)
   qa <- nlm(jsreg, qa$estimate, y = y, x = x, d = d)
@@ -64,7 +65,8 @@ js.compreg <- function(y, x, con = TRUE, B = 1, ncores = 1, xnew = NULL) {
 
     } else {
       runtime <- proc.time()
-      #suppressWarnings()
+      oop <- options( warn = -1 )
+      on.exit( options(oop) )
       requireNamespace("doParallel", quietly = TRUE, warn.conflicts = FALSE)
       cl <- parallel::makePSOCKcluster(ncores)
       doParallel::registerDoParallel(cl)
