@@ -13,7 +13,8 @@ mix.compnorm.contour <- function(mod, type = "alr", n= 100, x = NULL, cont.line
   x1 <- seq(0.001, 0.999, length = n)
   sqrt3 <- sqrt(3)
   x2 <- seq(0.001, sqrt3/2 - 0.001, length = n)
-  #suppressWarnings()
+  oop <- options( warn = -1 )
+  on.exit( options(oop) )
 
   prob <- mod$prob
   mu <- mod$mu
